'''
Rhine Python Library
(c) Speare Inc. 2015
'''

extraction = lambda o: {'extraction': o}
closest = lambda o: {'closest': o}
equivalence = lambda x, y: {'equivalence': (x, y)}
subclass = lambda x, y: {'subclass': (x, y)}
distance = lambda x, y: {'distance': (x, y)}
clustering = lambda os: {'clustering': os}
